/**********************************************
 DATA MANAGEMENT TASKS USING SAS

 FILENAME: datamgt.sas
**********************************************/
/*Specify generic output using Options Formchar= */
options formchar="|----|+|---+=|-/\<>*";
libname sasdata2 "c:\users\kwelch\desktop\sasdata2";
title;

/*Read in the raw data. Set up variable labels.*/
data march;
  infile "marflt.dat";
  input    flight 1-3
           	@4 date mmddyy6.
			@10 time time5.
			orig $ 15-17
			dest $ 18-20
			@21 miles comma5.
			mail 26-29
			freight 30-33
			boarded 34-36
			transfer 37-39
			nonrev 40-42
			deplane 43-45
			capacity 46-48;
format date mmddyy10. time time5. miles comma5.;

           label flight="Flight number"
		          orig  ="Origination City"
				  dest  ="Destination City";
run;

/*MAKE A COPY OF A DATA SET*/
data newmarch;
   set march;
run;

/*MAKE A COPY OF A PERMANENT DATA SET*/
data sasdata2.bank2;
  set sasdata2.bank;
run;

/*CREATE A SUBSET OF DATA*/
data march15;
   set work.march;
   if date = "15MAR1990"d;
run;

proc print data=march15; 
run;

data london;
   set march; 
	if dest="LON";
run;

data longflt;
   set march;
   if miles >=1000;
run;

/*DELETE CASES FROM A DATASET*/
data shortflt;
   set march;
   if miles >=1000 then delete;
run;

/*Keep or Drop Observations*/
data march_passngrs;
   set march;
   keep date time orig dest miles boarded transfer nonrev deplane capacity;
run;

data march_passngrs;
   set march;
   drop mail freight;
run;

/*Create New Variables Using Transformations
  and Recodes*/
data march_recode;
   set march;
   totpassngrs = boarded + transfer + nonrev;
   empty_seats = capacity - totpassngrs;
   totnonpass  = mail + freight;
   pctfull = (totpassngrs/capacity)*100;
   
   logpassngrs = log(totpassngrs);
   totpassngrs2 = sum(boarded,transfer,nonrev);
   int_pctfull = int(totpassngrs/capacity)*100;
   rnd_pctfull = round(pctfull,.1); 

   if pctfull = 100 then full_flight = 1;
   else full_flight = 0;
   if pctfull = . then full_flight = .;

   if pctfull not=. then do;
      if pctfull < 25 then full_cat = 1;
      if pctfull >=25 and pctfull <50 then full_cat=2;
      if pctfull >=50 and pctfull <75 then full_cat=3;
      if pctfull >=75 then full_cat=4;
   end;

   if dest = "CPH" or dest="FRA" or dest = "LON" 
     or dest = "PAR" or dest = "YYZ" then USA = 0;
   if dest in("DFW", "LAX", "ORD", "WAS") then USA = 1;
run;  

title "Check New Variables";
proc means data=march_recode;
run;

proc freq data=march_recode;
  tables full_flight full_cat dest USA;
run;

/*SORT*/
proc sort data=march_recode;
  by USA;
run;
title "Descriptive Statistics by US vs Non-US Destinations";
proc means data=march_recode;
  by USA;
run;

/*SORT BY MORE THAN ONE VARIABLE*/
proc sort data=march_recode;
     by date USA;
run;
title "Descriptive Statistics by Date and Destination";
proc means data=march_recode;
     by date USA;
run;
/*Using the Tagsort Option*/
proc sort data=march_recode tagsort;
     by date dest;
run;

/*CREATE A SORTED OUTPUT DATA SET*/
proc sort data=march_recode out=sortdat;
     by date dest;
run;


/*SELECT CASES FOR AN ANALYSIS*/

/*Select cases based on values of a character variable*/
title "Flights to Los Angeles";
proc print data=march_recode;
    where dest = "LAX";
    var flight dest totpassngrs;
run;

title "Missing Destination";
proc print data=march_recode;
    where dest = " ";
    var flight dest totpassngrs;
run;

/*Select cases based on values of a numeric variable*/
title "Flights Less than 30 Percent Full";
proc print data=march_recode;
 where pctfull < 30;
 var dest date pctfull;
run;

/*Using Where with Between*/
title "Flights Between 25 and 30 Percent Full";
proc print data=march_recode;
 where pctfull between 25 and 35 ;
 var flight dest totpassngrs pctfull;
run;

/*Select Cases that are missing on a numeric variable*/
title "Cases Where Number of Passengers is Missing";
proc print data=march_recode;
    where totpassngrs = . ;
    var flight dest totpassngrs;
run;

/*Select cases based on a more complicated selection*/
title "Flights less than 60 percent full to London";
proc print data=march_recode;
    where (pctfull < 60) and (dest="LON") ;
    var flight dest totpassngrs capacity pctfull;
run;

/*Select cases based on values of a date variable*/
title "Flights on March 7th, 1990"; 
proc print data=march_recode;
    where date = "07MAR90"D;
run;

title "Flights March 7th to March 9th , 1990"; 
proc print data=march_recode;
    where date between "07MAR90"D and "09MAR90"D;
run;

title "Cases with Missing Date";
proc print data= march_recode;
    where date = .;
    var flight dest date;
run;

/*************************************************
 Combine Data Sets
*************************************************/

/*CREATE BOYS AND GIRLS DATA SETS*/

data boys;
     input name  $ sex $ age height teacher $;
     cards;
Tom      M 12 62 Smith
Bob      M 13 57 Green
Joe      M 11 59 Green
Harry    M 12 53 Green
William  M 13 60 Smith
John     M 11 57 Smith
Richard  M 11 55 Green
     ;
title "Boys Dataset";
proc contents data=boys varnum;
run;

data girls;
     length name $ 10;
     input name $ age sex $ teacher $;
     cards;
Sharice  13 F  Smith
Mary     12 F  Smith
Ellen    11 F  Green
Carol    11 F  Green
Chris    13 F  Smith
Claire   12 F  Green
Raye     13 F  Smith
Wilhelmina 12 F Green
     ;
title "Girls Data";
proc contents data=girls varnum;
run;
proc print data=girls;
run;

/*APPEND DATA SETS USING THE SET STATEMENT*/

data allkids;
     length name $ 10;
     set boys girls;
run;
title "printout of allkids dataset";
title2 "with boys first in the data set";
proc print data = allkids;
run;
proc contents data=allkids varnum;
run;


/*SWITCH THE ORDER OF THE TWO DATA SETS*/
data allkids2;
    set girls boys;
run;
title "printout of allkids2 dataset";
title2 "with girls first in the data set";
proc print data = allkids2;
run;


**********************************************************;
*Merging datasets that have different variables;
**********************************************************;
data exam;
     input id examdate mmddyy10. sex age height weight sbp dbp;
     format examdate mmddyy10.;
     cards;
1 10/18/2000 1 25 72 156 128 89
2 05/29/2000 1 33 68 168 145 96
3 02/21/2000 1 47 65 182 152 98
4 06/17/2000 1 29 69 190 139 91
5 01/11/2000 2 37 62 129 145 93
6 08/15/2000 2 42 64 156 133 94
;

data lab;
    input id hgb;
    cards;
1  13.2
4  12.1
3  14.5
6  12.8
12 13.0
;
proc sort data=exam;
   by id;
run;
proc sort data=lab;
   by id;
run;

data exam_lab;
    merge exam lab;
    by id;
run;
title "Printout of Exam_lab Data Set";
proc print;
run;

/*INCLUDE ONLY CASES THAT ARE IN BOTH DATA SETS*/

data exam_lab2;
     merge exam(in=a) lab(in=b);
     by id;
     if a and b;
run;
title "Exam_lab2 Data Set Includes Only Those";
title2 "In Both Data Sets";
proc print data=exam_lab2;
run;

/*INCLUDE CASES THAT ARE IN EXAM, WHETHER THEY
   ARE IN LAB OR NOT*/

data exam_lab3;
     merge exam(in=a) lab(in=b);
     by id;
     if a;
run;

title "Exam_lab3 Data Set Includes Those";
title2 "In Exam Data, Regardless of Lab Data";
proc print data=exam_lab3;
run;

 
/*INCLUDE CASES FROM LAB, WHETHER THEY ARE IN EXAM
  OR NOT*/

data exam_lab4;
     merge exam(in=a) lab(in=b);
     by id;
     if b;
run;

title "Exam_lab4 Data Set Includes Those";
title2 "In Lab Data, Regardless of Exam Data";
proc print data=exam_lab4;
run;

**********************************************************;
*MERGING DATA SETS THAT HAVE THE SAME VARIABLE NAMES
**********************************************************;

data oldsal;
     input name $ idnum sex $ age salary jobcat year;
     cards;
 Roger  518 M 45 7677 2 1989
 Martha 321 F 28 5000 1 1989
 Zeke   444 M 33 6075 1 1989
 Barb  1728 F 40 9023 2 1989
 Bill   993 M 36 7739 3 1989
 Sandy 1002 F 29 6161 3 1989
     ;
data newsal;
     input name $ idnum salary jobcat year;
     cards;
 Hank    108 11138 1 1995
 Fred    519 10035 2 1995
 Zeke    444  9697 1 1995
 Martha  321  7987 2 1995
 Sandy  1002  6995 2 1995
 Bill    993 12400 3 1995
 Roxy    773 10119 2 1995
     ;

/*merging by idnum*/
proc sort data=oldsal;
    by idnum; 
run;

proc sort data=newsal;
    by idnum; 
run;

data combine1;
    merge oldsal(rename=(salary=salary89 jobcat=jobcat89))
          newsal(rename=(salary=salary95 jobcat=jobcat95));
    by idnum;
    drop year;
run;
title "printout of combine1 data set";
title2 "matching by id number";
title3 "all cases that were in either data set are included"; 
proc print data=combine1;
run;

/*merging by idnum, but keeping only cases that are in both datasets*/

data combine2;
    merge oldsal(in=a rename=(salary=salary89 jobcat=jobcat89)) 
          newsal(in=b rename=(salary=salary95 jobcat=jobcat95));  
    by idnum;
    if a and b;
    totsal = sum (salary89,salary95);
    format salary89 salary95 totsal dollar12.;
    drop year;
run;

title "printout of combine2 data set";
title2 "matching by id number";
title3 "and only including cases that are in both data sets"; 
proc print data=combine2;
run;

/*Merging Data from a Table with a Dataset 
  having multiple obs per group*/

PROC IMPORT OUT= WORK.AgeStudy 
            DATAFILE= "AgeStudy.xls" 
            DBMS=xls REPLACE;
     sheet="Sheet1"; 
RUN;

proc print data=Agestudy;
run;

PROC IMPORT OUT= WORK.Census 
            DATAFILE= "MI_census_2000.xls" 
            DBMS=xls REPLACE;
     sheet="Sheet1"; 
RUN;

proc sort data=census;
by county;
run;
proc sort data=agestudy;
by county;
run;

data study_census;
  length county $ 16;
  merge agestudy(in=instudy) census(in=incensus);
  by county;
  if instudy;
run;

title "Printout of Merged Data";
proc print data=study_census;
format Census_2000 comma12.;
run;


