/**********************************************
 This command file illustrates several commonly
  used statistical graphics using SAS using:
  Proc SGPLOT
  Proc SGPANEL
  Proc SGSCATTER
***********************************************/

libname sasdata2 "c:\users\kwelch\desktop\sasdata2";
ods listing sge = on;

/*Boxplots*/

title "Boxplot";
title2 "No Categories";
proc sgplot data=sasdata2.employee;
  vbox salary;
run;

title "Boxplot";
title2 "Category=Gender";
proc sgplot data=sasdata2.employee;
  vbox salary/ category=gender;
run; 

/*Paneled Boxplots*/

title "Boxplot with Panels";
proc sgpanel data=sasdata2.employee;
  panelby jobcat / rows=1 columns=3 ;
  vbox salary / category= gender;
run;
 
/*Barcharts*/

title "Vertical Bar Chart";
proc sgplot data=sasdata2.employee;
  vbar jobcat ;
run;

/*Clustered Bar Charts*/

title "Vertical Bar Chart";
title2 "Clustered by Gender";
proc sgplot data=sasdata2.employee;
  vbar jobcat /group=Gender groupdisplay=cluster ;
run;

/*Bar Chart with Mean and Error Bars*/

title "BarChart with Mean and Standard Deviation";
proc sgplot data=sasdata2.employee;
  vbar jobcat / response=salary limitstat = stddev
  limits = upper stat=mean;
run;

/*Bar Charts for Proportions of a Binary Variable*/

/*Bar chart with Mean of Indicator Variable*/
data afifi;
  set sasdata2.afifi;
  if survive=1 then died=0;
  if survive=3 then died=1;
run;
proc format;
  value shokfmt 2="Non-Shock"
                3="Hypovolemic"  
                4="Cardiogenic"
                5="Bacterial"
                6="Neurogenic"           
                7="Other";        
run;

title "Barchart of Proportion Died for each Shock Type";
proc sgplot data=afifi;
  vbar shoktype / response=died stat=mean;
  format shoktype shokfmt.;
run;


/*Paneled Bar Charts*/

title "BarChart Paneled by Gender";
proc sgpanel data=sasdata2.employee;
   panelby gender ;
   vbar jobcat / response=salary limitstat = stddev
      limits = upper stat=mean;
run;

/*Histograms*/

title "Histogram";
proc sgplot data=sasdata2.employee;
  histogram salary ;
run; 

/*Histogram with Normal Density Overlaid*/

title "Histogram With Density Overlaid";
proc sgplot data=sasdata2.employee;
  histogram salary ;
  density salary;
  density salary / type=kernel;
  keylegend / location = inside position = topright; 
run;

/*Paneled Histograms*/

title "Histogram with Panels";
title2 "Exclude Custodial";
proc sgpanel data=sasdata2.employee;
  where jobcat not=2;
  panelby   gender jobcat/  rows=2 columns = 2;
  histogram salary / scale=proportion; run;
/*use scale=proportion, count, or percent(default)*/

/*Overlaid Histograms*/

title "Overlay different variables";
proc sgplot data=sasdata2.employee;
  histogram salbegin ;
  histogram salary / transparency = .5;
run;

/*Create New Variables for Overlay*/
data employee2;
  set sasdata2.employee;
  if gender = "m" then salary_m = salary;
  if gender = "f" then salary_f = salary;
run;

/*Note: Transparency = 0 is opaque. Transparency = 1.0 is fully transparent.*/

title "Overlaid histograms";
title2 "Same variable, but two groups ";
proc sgplot data=employee2;
  histogram salary_m;
  histogram salary_f / transparency=0;
run;

/*Scatterplots*/

title "Scatterplot";
proc sgplot data=sasdata2.employee;
  scatter x=salbegin y=salary / group=gender ;
run;

/*Scatterplot with Confidence Ellipse*/

title "Scatterplot";
proc sgplot data=sasdata2.employee;
  scatter x=salbegin y=salary / group=gender ;
  ellipse x=salbegin y=salary / type=predicted alpha=.10;
run;

/*Scatterplot with Regression Line*/

title "Scatterplot with Regression Line";
title2 "Clerical Only";
proc sgplot data=sasdata2.employee;
  where jobcat=1;
  scatter x=prevexp y=salary / group=gender ;
  reg x=prevexp y=salary / cli clm nomarkers;
run;

/*Scatterplot with Separate Regression Lines
  for Subgroups*/

title "Scatterplot with Regression Line";
title2 "Separate Lines for Females and Males";
proc sgplot data=sasdata2.employee;
  where jobcat=1;
  reg x=prevexp y=salary / group=gender;
run;

/*Paneled Scatterplots with Loess Fit*/

title "Scatterplot Panels";
title2 "Loess Fit";
proc sgpanel data=sasdata2.employee;
   panelby jobcat / columns=3;
   scatter x=jobtime y=salary / group=gender;
   loess x=jobtime y=salary ;
run;

/*Scatterplot Matrix*/

title "Scatterplot Matrix"; 
title2 "Clerical Employees";
proc sgscatter data=sasdata2.employee;
  where jobcat=1;
  matrix salbegin salary jobtime prevexp / group=gender
                   diagonal=(histogram);
run;


/*Series Plots*/

PROC IMPORT OUT= WORK.autism 
            DATAFILE= "autism.csv" 
            DBMS=CSV REPLACE;
     GETNAMES=YES;
     DATAROW=2; 
RUN;

title "Spaghetti Plots for Each Child";
proc sgpanel data=autism;
  panelby sicdegp /columns=3;
  series x=age y=vsae / group=Childid 
  markers  legendlabel=" " lineattrs=(pattern=1 color=black); 
run;


/*Overlay Means on Plots*/

proc sort data=autism;
by sicdegp age;
run;
proc means data=autism noprint;
  by sicdegp age;
  output out=meandat mean(VSAE)=mean_VSAE;
run;
data autism2;
  merge autism meandat(drop=_type_ _freq_);
  by sicdegp age;
run;
title "Means Plots Overlaid on Data";
proc sgplot data=autism2;
  series x=age y=mean_VSAE / group=SICDEGP;
  scatter x=age y=VSAE ;
run;

/*Series Plot with Error Bars*/

data test;
  input  num_products beta stderror;
  upper = beta + stderror;
  lower = beta - stderror;
  cards;
0  0   0
1 .5  .5
2  1  .6
3  1  .7
4  2  .8
;
proc print data=test;
run;

ods listing sge=on;

proc sgplot data=test noautolegend ;
  series x=num_products y=beta / 
         markers markerattrs=(symbol=diamondfilled color=brown );
  highlow x = num_products high=upper low=lower 
          / lowcap=serif highcap=serif;
  yaxis values = (-.5 to 3.5 by .5) ;
  xaxis offsetmin=.1 offsetmax=.1;
  label num_products = "Number of additional products used" ;
  label upper="B";
run; 


/*Using formats to make graphs more readable*/

proc format;
   value jobcat 1="Clerical"
                2="Custodial"
			    3="Manager";
   value $Gender "f"="Female"
                 "m"="Male";
run;

title "Boxplot with Panels";
proc sgpanel data=sasdata2.employee;
  panelby jobcat / rows=1 columns=3 novarname;
  vbox salary / category= gender ;
  format gender $gender.;
  format jobcat jobcat.;
run;


/*Creating PDF Output*/

ods pdf style=journal2;
ods pdf file = "testing.pdf";
ods listing close;
title "PDF Output";
proc sgpanel data=sasdata2.employee;
   panelby jobcat;
   scatter x=jobtime y=salary / group=gender;
   loess x=jobtime y=salary ;
run;
ods pdf close;
ods listing;

/*Creating HTML Output*/

/*Creating HTML output*/
ods html style=statistical;
ods html file = "testing.html";
ods listing close;
title "HTML Output";
proc sgpanel data=sasdata2.employee;
   panelby jobcat / columns=3 novarname;
   scatter x=jobtime y=salary / group=gender;
   loess x=jobtime y=salary/ nomarkers;
   format jobcat jobcat.;
run;
ods html close;
ods listing;
ods html style=htmlblue;


/*Traditional SAS Graphics*/

/*Creating a Regression Plot Using Proc Gplot*/

symbol1 value=dot height=.5 interpol=rl ;
title "Regression Plot for Salary";
proc gplot data=sasdata2.employee;
  plot salary * prevexp ;
run; quit;
